
/*]  Copyright (c) 2009-2010, Charles McGarvey  [**************************
**]  All rights reserved.
*
* vi:ts=4 sw=4 tw=75
*
* Distributable under the terms and conditions of the 2-clause BSD license;
* see the file COPYING for a complete text of the license.
*
**************************************************************************/

#include <moof/log.hh>
#include <moof/sound.hh>

#include "Heroine.hh"
	
Heroine::Heroine() :
	Character("Heroine") {}


void Heroine::update(moof::scalar t, moof::scalar dt)
{
	Character::update(t, dt);

	moof::vector3 at(0.0, 0.0, 0.0);
	const moof::vector3 up(0.0, 1.0, 0.0);

	if (state_.velocity[0] < 0.0) at[0] = -1.0;
	else                          at[0] = 1.0;

	moof::sound::listener_position(moof::promote(state_.position));
	moof::sound::listener_velocity(moof::promote(state_.velocity));
	moof::sound::listener_orientation(at, up);
}


bool Heroine::handle_event(const moof::event& event)
{
	moof::scalar force = 40.0;
	
	switch (event.type)
	{
		case SDL_KEYDOWN:
			if (event.key.keysym.sym == SDLK_a)
			{
				state_.force += moof::vector2(-force, 0.0);
				return true;
			}
			else if (event.key.keysym.sym == SDLK_d)
			{
				state_.force += moof::vector2(force, 0.0);
				return true;
			}
			else if (event.key.keysym.sym == SDLK_s)
			{
				state_.force += moof::vector2(0.0, -force);
				return true;
			}
			else if (event.key.keysym.sym == SDLK_w)
			{
				state_.force += moof::vector2(0.0, force);
				return true;
			}

		case SDL_KEYUP:
			if (event.key.keysym.sym == SDLK_a)
			{
				state_.force += moof::vector2(force, 0.0);
				return true;
			}
			else if (event.key.keysym.sym == SDLK_d)
			{
				state_.force += moof::vector2(-force, 0.0);
				return true;
			}
			else if (event.key.keysym.sym == SDLK_s)
			{
				state_.force += moof::vector2(0.0, force);
				return true;
			}
			else if (event.key.keysym.sym == SDLK_w)
			{
				state_.force += moof::vector2(0.0, -force);
				return true;
			}
	}
	return false;
}

